import { getAnalytics, logEvent } from "firebase/analytics";
import { initializeApp } from "firebase/app";
import { child, getDatabase, onValue, ref } from "firebase/database";
export function addLocationListener(pullKey, callback) {
    return forPullKey(pullKey).addLocationListener(callback);
}
export function addSpeedListener(pullKey, callback) {
    return forPullKey(pullKey).addSpeedListener(callback);
}
export function addHeadingListener(pullKey, callback) {
    return forPullKey(pullKey).addHeadingListener(callback);
}
export function addAltitudeListener(pullKey, callback) {
    return forPullKey(pullKey).addAltitudeListener(callback);
}
export function addSessionIdListener(pullKey, callback) {
    return forPullKey(pullKey).addSessionIdListener(callback);
}
/** Creates a listener source for a streamer's private data with a pull key. */
export function forPullKey(pullKey) {
    var db = getDatabase(getApp());
    var analytics = getAnalytics(getApp());
    var reference = child(ref(db, "pullables"), pullKey);
    return {
        addLocationListener: function (callback) {
            logEvent(analytics, "listener", { type: "location", pullKey: pullKey });
            return onValue(child(reference, "location"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        addSpeedListener: function (callback) {
            logEvent(analytics, "listener", { type: "speed", pullKey: pullKey });
            return onValue(child(reference, "speed"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        addHeadingListener: function (callback) {
            logEvent(analytics, "listener", { type: "heading", pullKey: pullKey });
            return onValue(child(reference, "heading"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        addAltitudeListener: function (callback) {
            logEvent(analytics, "listener", { type: "altitude", pullKey: pullKey });
            return onValue(child(reference, "altitude"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        addHeartRateListener: function (callback) {
            logEvent(analytics, "listener", { type: "heartRate", pullKey: pullKey });
            return onValue(child(reference, "heartRate"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        addCyclingPowerListener: function (callback) {
            logEvent(analytics, "listener", { type: "cyclingPower", pullKey: pullKey });
            return onValue(child(reference, "cyclingPower"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        addCyclingCrankListener: function (callback) {
            logEvent(analytics, "listener", { type: "cyclingCrank", pullKey: pullKey });
            return onValue(child(reference, "cyclingCrank"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        addCyclingWheelListener: function (callback) {
            logEvent(analytics, "listener", { type: "cyclingWheel", pullKey: pullKey });
            return onValue(child(reference, "cyclingWheel"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        /**
         * This listener reports the number of steps taken so far. Note that this
         * number does not reset when the streamer goes offline. It is up to the
         * client to reset the number when the streamer goes offline or online.
         * Instead, the number is reported as the total number of steps taken since
         * an arbitrary point in time, and guaranteed to be monotonically increasing
         * for a given session id.
         */
        addPedometerStepsListener: function (callback) {
            logEvent(analytics, "listener", { type: "pedometerSteps", pullKey: pullKey });
            return onValue(child(reference, "pedometerSteps"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
        /**
         * This listener is useful for accessing unstructured data associated with
         * the pull key. It includes the above fields as well as other fields such
         * as bluetooth heart rate or telemetry data.
         */
        addListener: function (callback) {
            logEvent(analytics, "listener", { type: "root", pullKey: pullKey });
            return onValue(reference, function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "root", pullKey: pullKey });
            });
        },
        /**
         * This listener detects changes in the active session id. When a streamer
         * goes online, a new session id is created and this listener is triggered.
         * null sessionId's indicate the streamer is offline. Note that it is
         * possible for two sequential non-null sessionIds to be sent.
         */
        addSessionIdListener: function (callback) {
            logEvent(analytics, "listener", { type: "sessionId", pullKey: pullKey });
            return onValue(child(reference, "sessionId"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "sessionId", pullKey: pullKey });
            });
        },
    };
}
/** Creates a listener source for a streamer's public data. */
export function forStreamer(provider, userId) {
    var db = getDatabase(getApp());
    var analytics = getAnalytics(getApp());
    var reference = child(ref(db, "streamers"), "".concat(provider, ":").concat(userId));
    return {
        /** If the public location is hidden (eg streamer is offline), null is passed. */
        addLocationListener: function (callback) {
            logEvent(analytics, "listener", { type: "location", provider: provider, userId: userId });
            return onValue(child(reference, "location"), function (snapshot) {
                callback(snapshot.val());
                logEvent(analytics, "data", { type: "location", provider: provider, userId: userId });
            });
        },
    };
}
var app = null;
function getApp() {
    if (!app) {
        app = initializeApp({
            apiKey: "AIzaSyC4L8ICZbJDufxe8bimRdB5cAulPCaYVQQ",
            databaseURL: "https://rtirl-a1d7f-default-rtdb.firebaseio.com",
            projectId: "rtirl-a1d7f",
            appId: "1:684852107701:web:d77a8ed0ee5095279a61fc",
            measurementId: "G-TR97D81LT3",
        }, "rtirl-api");
    }
    return app;
}
